# keplertools
Two-body orbital propagation tools

![Build Status](https://github.com/dsavransky/keplertools/actions/workflows/ci.yml/badge.svg)
[![Coverage Status](https://coveralls.io/repos/github/dsavransky/keplertools/badge.svg?branch=main)](https://coveralls.io/github/dsavransky/keplertools?branch=main)
[![Documentation Status](https://readthedocs.org/projects/keplertools/badge/?version=latest)](https://keplertools.readthedocs.io/en/latest/?badge=latest)
[![PyPI version](https://badge.fury.io/py/keplertools.svg)](https://badge.fury.io/py/keplertools)

## Installation

```
pip install keplertools
```

To install from source, clone or download the repository, and, in the top level directory run:

```
pip install .
```

Installing from source requires a C compiler.  See here for details: https://cython.readthedocs.io/en/latest/src/quickstart/install.html

## Documentation

https://keplertools.readthedocs.io/

## Acknowledgements

Portions of this code are adapted from orvara (https://github.com/t-brandt/orvara).
